/******************************************************************************
  This is example sketch for Arduino.
  Shows how to control SimpleBGC-driven gimbal via Serial API.
  API specs are available at http://www.basecamelectronics.com/
  
  Connection: 
    Arduino GND -> SimpleBGC GND
    Arduino TX -> SimpleBGC RX
    
    Power Arduino separatly or via +5V from onboard FTDI connector

  (C) Aleksey Moskalenko
*******************************************************************************/
#include <inttypes.h>


// default is 115200 but may be changed in the Advanced tab of the SimpleBGC GUI
#define SERIAL_SPEED 115200 

// Definitions for Serial API commands used in this example
#define SBGC_CMD_SERVO_OUT  36




typedef struct {
  int16_t servo1;
  int16_t servo2;
  int16_t servo3;
  int16_t servo4;
  int16_t servo5;
  int16_t servo6;
  int16_t servo7;
  int16_t servo8;
} SBGC_cmd_servo_out_data;




// This helper function formats and sends a command to SimpleBGC Serial API
void SBGC_sendCommand(uint8_t cmd, void *data, uint8_t size) {
  uint8_t i, checksum=0;
  
  // Header
  Serial.write('>');
  Serial.write(cmd);
  Serial.write(size);
  Serial.write(cmd+size);
  // Body
  for(i=0;i<size;i++) {
    checksum+= ((uint8_t*)data)[i];
    Serial.write(((uint8_t*)data)[i]);
  }
  Serial.write(checksum);
}
/*****************************************************************************/




// All servo outputs are disabled (not occupied and floating)
SBGC_cmd_servo_out_data s = { -1, -1, -1, -1, -1, -1, -1, -1 };


void setup() { 
  Serial.begin(SERIAL_SPEED);

	// Use servo1 output (labeled as FC_ROLL) and  set it to low level (no PWM generation)
	s.servo1 = 0; 
	SBGC_sendCommand(SBGC_CMD_SERVO_OUT, &s, sizeof(s));
	delay(1000);
} 


void loop() { 
  // Move servo1 to neutral position
	s.servo1 = 1500;
	SBGC_sendCommand(SBGC_CMD_SERVO_OUT, &s, sizeof(s));
	delay(1000);


  // Slowly move servo1 from neutral position to top
  for(s.servo1=1500; s.servo1<2500; s.servo1+= 10) {
	  SBGC_sendCommand(SBGC_CMD_SERVO_OUT, &s, sizeof(s));
  	delay(100);
  }

  // Slowly move servo1 from top to bottom
  for(s.servo1=2500; s.servo1>500; s.servo1-= 10) {
	  SBGC_sendCommand(SBGC_CMD_SERVO_OUT, &s, sizeof(s));
  	delay(100);
  }
} 
